camera = {}
camera.x = 0
camera.y = 0
camera.scaleX = 1
camera.scaleY = 1
camera.rotation = 0

function camera:set()
  love.graphics.push()
  love.graphics.rotate(-self.rotation)
  love.graphics.scale(1 / self.scaleX, 1 / self.scaleY)
  love.graphics.translate(-self.x, -self.y)
end

function camera:unset()
  love.graphics.pop()
end

function camera:move(dx, dy)
  self.x = self.x + (dx or 0)
  self.y = self.y + (dy or 0)
end

function camera:rotate(dr)
  self.rotation = self.rotation + dr
end

function camera:scale(sx, sy)
  sx = sx or 1
  self.scaleX = self.scaleX * sx
  self.scaleY = self.scaleY * (sy or sx)
end

function camera:setPosition(x, y)
  self.x = x or self.x
  self.y = y or self.y
end

function camera:setScale(sx, sy)
  self.scaleX = sx or self.scaleX
  self.scaleY = sy or self.scaleY
end

function g2r(g)
	return math.pi/180 * g
end

function carRender()
	love.graphics.clear()
	love.graphics.setBlendMode("alpha")
	love.graphics.setColor(0xff, 0, 0)
	love.graphics.polygon("line", car.b:getWorldPoints(car.s:getPoints()))
	love.graphics.setColor(0xff, 0xff, 0xff)
	love.graphics.polygon("fill", car.b:getWorldPoints(car.s:getPoints()))
end

function love.load()
	love.graphics.setLineWidth(5)
	-- love.graphics.setBackgroundColor(54, 172, 248)
	alfombra = love.graphics.newImage("alfombra.png")
	world = love.physics.newWorld()
	window = {}
		window.w, window.h = love.graphics.getDimensions()
	car = {}
		car.b = love.physics.newBody(world, window.w/2, window.h/2, "dynamic")
		car.s = love.physics.newRectangleShape(24, 48)
		car.f = love.physics.newFixture(car.b, car.s)
		car.stat = {}
			car.stat.v = 100
			car.stat.pos = {}
				car.stat.pos.x, car.stat.pos.y = car.s:getPoints()

	-- j1 = love.joystick.getJoysticks()[1]

	canv1 = love.graphics.newCanvas()
	canv2 = love.graphics.newCanvas(window.w, window.h)
	love.graphics.setCanvas(canv1)
		love.graphics.clear()
		love.graphics.setBlendMode("alpha")
		love.graphics.setColor(125, 125, 125, 128)
		love.graphics.rectangle("fill", window.w/2 - alfombra:getWidth()/2, window.h/2 - alfombra:getHeight()/2, alfombra:getWidth(), alfombra:getHeight())
		love.graphics.setColor(255, 255, 255)
		love.graphics.print("N", window.w/2, window.h/2 - alfombra:getHeight()/2)
	love.graphics.setCanvas()
	canv2:renderTo(carRender)
	love.graphics.setScissor(-100, -100, window.w + 100, window.h + 100)
end

function love.update(dt)
	canv2:renderTo(carRender)
	world:update(dt)
	-- car.b:applyForce(math.cos(3 * math.pi/2 + car.b:getAngle()) * car.stat.v * j1:getGamepadAxis("triggerright"), math.sin(3 * math.pi/2 + car.b:getAngle()) * car.stat.v * j1:getGamepadAxis("triggerright"))
	-- car.b:applyForce(-math.cos(3 * math.pi/2 + car.b:getAngle()) * car.stat.v * j1:getGamepadAxis("triggerleft"), -math.sin(3 * math.pi/2 + car.b:getAngle()) * car.stat.v * j1:getGamepadAxis("triggerleft"))
	--if math.abs(j1:getGamepadAxis("leftx")) >= 0.07 then
	--	car.b:setAngle(car.b:getAngle() + g2r(j1:getGamepadAxis("leftx")))
	--end
	if love.keyboard.isDown("up") then
		car.b:applyForce(math.cos(3 * math.pi/2 + car.b:getAngle()) * car.stat.v, math.sin(3 * math.pi/2 + car.b:getAngle()) * car.stat.v)
	elseif love.keyboard.isDown("down") then
		car.b:applyForce(-math.cos(3 * math.pi/2 + car.b:getAngle()) * car.stat.v, -math.sin(3 * math.pi/2 + car.b:getAngle()) * car.stat.v)
	else
		car.b:applyForce(0, 0)
	end

	if love.keyboard.isDown("left") then
		car.b:setAngle(car.b:getAngle() - g2r(1))
	elseif love.keyboard.isDown("right") then
		car.b:setAngle(car.b:getAngle() + g2r(1))
	end

	x, y = car.b:getWorldPoints(car.s:getPoints())
	camera:setPosition(x - window.w/2 + 12, y - window.h/2 + 24)
end

function love.draw()
	camera:set()
	love.graphics.setColor(0xff, 0xff, 0xff)
	love.graphics.draw(canv1)
	love.graphics.draw(canv2)
	-- love.graphics.polygon("fill", car.b:getWorldPoints(car.s:getPoints()))
	love.graphics.rectangle("line", 0, 0, window.w, window.h)
	camera:unset()
end
